PyXMake Developer Guide: PyXMake.VTL.ssh_make Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.ssh_make Namespace Reference

## Functions
| main (BuildID, user, key, path2src=os.path.join(__mcd_core_path,"src"), path2feature=os.path.join(__mcd_core_path,"solver"), files=VTL.GetSourceCode(0), source_file="mcd_astandard.f", version="abq2019", makeopt=0, scratch=VTL.Scratch, dependency=posixpath.join(Utility.AsDrive("cluster", posixpath.sep),"software","mcodac","stable"), verbosity=2, host="129.247.54.37", port=22, **kwargs)

## Variables
| parser
| metavar
| nargs
| help
| _ = sys.argv[1]
| args
| BuildID = args.BuildID[0]
| user = args.user[0]
| key = args.key[0]
| path2src = args.source_path[0]
| path2feature = args.feature_path[0]
| output
| files
| scratch
| makeopt
| version

## Detailed Description

    Minimum working example for PyXMake.

    @note: Compile the complete MCODAC library for ABAQUS remotely.
    Created on 25.06.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake
          - Adopt Paths.log according to your system settings.

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.ssh_make.main | ( |  | BuildID,
|  |  | user,
|  |  | key,
|  |  | path2src = os.path.join(__mcd_core_path,"src"),
|  |  | path2feature = os.path.join(__mcd_core_path,"solver"),
|  |  | files = VTL.GetSourceCode(0),
|  |  | source_file = "mcd_astandard.f",
|  |  | version = "abq2019",
|  |  | makeopt = 0,
|  |  | scratch = VTL.Scratch,
|  |  | dependency = posixpath.join(Utility.AsDrive("cluster",posixpath.sep),"software","mcodac","stable"),
|  |  | verbosity = 2,
|  |  | host = "129.247.54.37",
|  |  | port = 22,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 56 of file ssh_make.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.ssh_make._ = sys.argv[1]
| protected

Definition at line 185 of file ssh_make.py.

## ◆ args

PyXMake.VTL.ssh_make.args

Definition at line 186 of file ssh_make.py.

## ◆ BuildID

str PyXMake.VTL.ssh_make.BuildID = args.BuildID[0]

Definition at line 191 of file ssh_make.py.

## ◆ files

PyXMake.VTL.ssh_make.files

Definition at line 207 of file ssh_make.py.

## ◆ help

PyXMake.VTL.ssh_make.help

Definition at line 178 of file ssh_make.py.

## ◆ key

PyXMake.VTL.ssh_make.key = args.key[0]

Definition at line 193 of file ssh_make.py.

## ◆ makeopt

PyXMake.VTL.ssh_make.makeopt

Definition at line 207 of file ssh_make.py.

## ◆ metavar

PyXMake.VTL.ssh_make.metavar

Definition at line 178 of file ssh_make.py.

## ◆ nargs

PyXMake.VTL.ssh_make.nargs

Definition at line 178 of file ssh_make.py.

## ◆ output

PyXMake.VTL.ssh_make.output

Definition at line 206 of file ssh_make.py.

## ◆ parser

PyXMake.VTL.ssh_make.parser

Initial value:
1= argparse.ArgumentParser(description="Build MCODAC's shared library remotely and its subsidiaries on the institute cluster.\
2 Supported features are ABAQUS, ANSYS & NASTRAN")

Definition at line 176 of file ssh_make.py.

## ◆ path2feature

PyXMake.VTL.ssh_make.path2feature = args.feature_path[0]

Definition at line 195 of file ssh_make.py.

## ◆ path2src

PyXMake.VTL.ssh_make.path2src = args.source_path[0]

Definition at line 194 of file ssh_make.py.

## ◆ scratch

PyXMake.VTL.ssh_make.scratch

Definition at line 207 of file ssh_make.py.

## ◆ user

PyXMake.VTL.ssh_make.user = args.user[0]

Definition at line 192 of file ssh_make.py.

## ◆ version

PyXMake.VTL.ssh_make.version

Definition at line 218 of file ssh_make.py.